summaryrefslogtreecommitdiffstats
path: root/perl-install/any.pm
diff options
context:
space:
mode:
authorAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
committerAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
commitb669b354a83790133e9d1be5c7796594bf9cfe22 (patch)
treeaa0ec2ee89a4aee11369bb5ebb3f3997526438b3 /perl-install/any.pm
parent14d4269e46245ec89e8106428f558973b127d3b2 (diff)
downloaddrakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.gz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.bz2
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.xz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.zip
- use 'cannot' instead of 'can not'
- use 'LDAP' instead of 'Ldap'
Diffstat (limited to 'perl-install/any.pm')
-rw-r--r--perl-install/any.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perl-install/any.pm b/perl-install/any.pm
index 90dce2613..24d4a9e53 100644
--- a/perl-install/any.pm
+++ b/perl-install/any.pm
@@ -434,7 +434,7 @@ sub setupBootloader__general {
my $ok = $b->{password} eq $b->{password2}
or $in->ask_warn('', [ N("The passwords do not match"), N("Please try again") ]);
my $ok2 = !($b->{password} && $b->{method} eq 'grub-graphic')
- or $in->ask_warn('', N("You can not use a password with %s",
+ or $in->ask_warn('', N("You cannot use a password with %s",
bootloader::method2text($b->{method})));
$ok && $ok2;
} },
@@ -1438,7 +1438,7 @@ sub ask_window_manager_to_logout {
);
my $cmd = $h{$wm} or return;
if (member($wm, 'ksmserver', 'kwin', 'gnome-session') && $> == 0) {
#- we can not use dcop when we are root
if (my $user = $ENV{USERHELPER_UID} && getpwuid($ENV{USERHELPER_UID})) {
$cmd = "su $user -c '$cmd'";
} else {
@@ -1438,7 +1438,7 @@ sub ask_window_manager_to_logout {
my $cmd = $h{$wm} or return;
if (member($wm, 'ksmserver', 'kwin', 'gnome-session') && $> == 0) {
- #- we can not use dcop when we are root
+ #- we cannot use dcop when we are root
if (my $user = $ENV{USERHELPER_UID} && getpwuid($ENV{USERHELPER_UID})) {
$cmd = "su $user -c '$cmd'";